@@ -1,6 +1,9 @@
 use std::{fmt, fmt::Write, str::FromStr};
 
+use arrayvec::ArrayVec;
+
 use shakmaty::{
+    fen::ParseFenError,
     Color,
     Color::{Black, White},
     Role,
@@ -10,6 +13,12 @@ use shakmaty::{
 #[derive(Clone, Debug)]
 pub struct ParseRetroPocketError;
 
+impl From<ParseRetroPocketError> for ParseFenError {
+    fn from(_: ParseRetroPocketError) -> Self {
+        ParseFenError::InvalidPocket
+    }
+}
+
 /// A [`RetroBoard`](crate::RetroBoard) pocket with a counter for each piece type.
 /// It stores the pieces than can be uncaptured by each color.    
 /// `self.unpromotion` is the number of pieces than can unpromote into a pawn.
@@ -134,10 +143,10 @@ impl FromStr for RetroPocket {
 
 impl IntoIterator for RetroPocket {
     type Item = Role;
-    type IntoIter = std::vec::IntoIter<Self::Item>;
+    type IntoIter = arrayvec::IntoIter<Self::Item, 5>;
 
     fn into_iter(self) -> Self::IntoIter {
-        let mut v: Vec<Role> = vec![];
+        let mut v: ArrayVec<Role, 5> = ArrayVec::new();
         if self.pawn > 0 {
             v.push(Role::Pawn)
         };
